@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -66,97 +66,97 @@ import java.util.ListResourceBundle;
 public class FormatData_ce extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] metaValue_generic_DayNames = new String[] {
+            "\u043a\u04c0\u0438\u0440\u0430",
+            "\u043e\u0440\u0448\u043e\u0442",
+            "\u0448\u0438\u043d\u0430\u0440\u0430",
+            "\u043a\u0445\u0430\u0430\u0440\u0430",
+            "\u0435\u0430\u0440\u0430",
+            "\u043f\u04c0\u0435\u0440\u0430\u0441\u043a\u0430",
+            "\u0448\u0443\u043e\u0442",
+        };
+        final String[] metaValue_generic_DayAbbreviations = new String[] {
+            "\u043a\u04c0\u0438",
+            "\u043e\u0440",
+            "\u0448\u0438",
+            "\u043a\u0445\u0430",
+            "\u0435\u0430",
+            "\u043f\u04c0\u0435",
+            "\u0448\u0443\u043e",
+        };
+        final String[] metaValue_generic_QuarterNames = new String[] {
+            "1-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
+            "2-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
+            "3-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
+            "4-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
+        };
+        final String[] metaValue_generic_QuarterAbbreviations = new String[] {
+            "1-\u0433\u04c0\u0430 \u043a\u0432.",
+            "2-\u0433\u04c0\u0430 \u043a\u0432.",
+            "3-\u0433\u04c0\u0430 \u043a\u0432.",
+            "4-\u0433\u04c0\u0430 \u043a\u0432.",
+        };
+        final String[] metaValue_generic_QuarterNarrows = new String[] {
+            "1",
+            "2",
+            "3",
+            "4",
+        };
         final String[] metaValue_MonthNames = new String[] {
-               "\u044f\u043d\u0432\u0430\u0440\u044c",
-               "\u0444\u0435\u0432\u0440\u0430\u043b\u044c",
-               "\u043c\u0430\u0440\u0442",
-               "\u0430\u043f\u0440\u0435\u043b\u044c",
-               "\u043c\u0430\u0439",
-               "\u0438\u044e\u043d\u044c",
-               "\u0438\u044e\u043b\u044c",
-               "\u0430\u0432\u0433\u0443\u0441\u0442",
-               "\u0441\u0435\u043d\u0442\u044f\u0431\u0440\u044c",
-               "\u043e\u043a\u0442\u044f\u0431\u0440\u044c",
-               "\u043d\u043e\u044f\u0431\u0440\u044c",
-               "\u0434\u0435\u043a\u0430\u0431\u0440\u044c",
-               "",
-            };
+            "\u044f\u043d\u0432\u0430\u0440\u044c",
+            "\u0444\u0435\u0432\u0440\u0430\u043b\u044c",
+            "\u043c\u0430\u0440\u0442",
+            "\u0430\u043f\u0440\u0435\u043b\u044c",
+            "\u043c\u0430\u0439",
+            "\u0438\u044e\u043d\u044c",
+            "\u0438\u044e\u043b\u044c",
+            "\u0430\u0432\u0433\u0443\u0441\u0442",
+            "\u0441\u0435\u043d\u0442\u044f\u0431\u0440\u044c",
+            "\u043e\u043a\u0442\u044f\u0431\u0440\u044c",
+            "\u043d\u043e\u044f\u0431\u0440\u044c",
+            "\u0434\u0435\u043a\u0430\u0431\u0440\u044c",
+            "",
+        };
         final String[] metaValue_MonthAbbreviations = new String[] {
-               "\u044f\u043d\u0432",
-               "\u0444\u0435\u0432",
-               "\u043c\u0430\u0440",
-               "\u0430\u043f\u0440",
-               "\u043c\u0430\u0439",
-               "\u0438\u044e\u043d",
-               "\u0438\u044e\u043b",
-               "\u0430\u0432\u0433",
-               "\u0441\u0435\u043d",
-               "\u043e\u043a\u0442",
-               "\u043d\u043e\u044f",
-               "\u0434\u0435\u043a",
-               "",
-            };
+            "\u044f\u043d\u0432",
+            "\u0444\u0435\u0432",
+            "\u043c\u0430\u0440",
+            "\u0430\u043f\u0440",
+            "\u043c\u0430\u0439",
+            "\u0438\u044e\u043d",
+            "\u0438\u044e\u043b",
+            "\u0430\u0432\u0433",
+            "\u0441\u0435\u043d",
+            "\u043e\u043a\u0442",
+            "\u043d\u043e\u044f",
+            "\u0434\u0435\u043a",
+            "",
+        };
         final String[] metaValue_MonthNarrows = new String[] {
-               "\u042f",
-               "\u0424",
-               "\u041c",
-               "\u0410",
-               "\u041c",
-               "\u0418",
-               "\u0418",
-               "\u0410",
-               "\u0421",
-               "\u041e",
-               "\u041d",
-               "\u0414",
-               "",
-            };
-        final String[] metaValue_DayNames = new String[] {
-               "\u043a\u04c0\u0438\u0440\u0430",
-               "\u043e\u0440\u0448\u043e\u0442",
-               "\u0448\u0438\u043d\u0430\u0440\u0430",
-               "\u043a\u0445\u0430\u0430\u0440\u0430",
-               "\u0435\u0430\u0440\u0430",
-               "\u043f\u04c0\u0435\u0440\u0430\u0441\u043a\u0430",
-               "\u0448\u0443\u043e\u0442",
-            };
-        final String[] metaValue_DayAbbreviations = new String[] {
-               "\u043a\u04c0\u0438",
-               "\u043e\u0440",
-               "\u0448\u0438",
-               "\u043a\u0445\u0430",
-               "\u0435\u0430",
-               "\u043f\u04c0\u0435",
-               "\u0448\u0443\u043e",
-            };
-        final String[] metaValue_QuarterNames = new String[] {
-               "1-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
-               "2-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
-               "3-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
-               "4-\u0433\u04c0\u0430 \u043a\u0432\u0430\u0440\u0442\u0430\u043b",
-            };
-        final String[] metaValue_QuarterAbbreviations = new String[] {
-               "1-\u0433\u04c0\u0430 \u043a\u0432.",
-               "2-\u0433\u04c0\u0430 \u043a\u0432.",
-               "3-\u0433\u04c0\u0430 \u043a\u0432.",
-               "4-\u0433\u04c0\u0430 \u043a\u0432.",
-            };
+            "\u042f",
+            "\u0424",
+            "\u041c",
+            "\u0410",
+            "\u041c",
+            "\u0418",
+            "\u0418",
+            "\u0410",
+            "\u0421",
+            "\u041e",
+            "\u041d",
+            "\u0414",
+            "",
+        };
         final String[] metaValue_Eras = new String[] {
-               "\u0432. \u044d. \u0442\u04c0. \u044f",
-               "\u0432. \u044d",
-            };
-        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
+            "\u0432. \u044d. \u0442\u04c0. \u044f",
+            "\u0432. \u044d",
+        };
         final String metaValue_calendarname_gregorian = "\u0433\u0440\u0438\u0433\u043e\u0440\u0438\u0430\u043d\u0430\u043d";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0448\u043e" },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "islamic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "standalone.DayNarrows",
                 new String[] {
                     "\u043a\u04c0",
@@ -168,28 +168,38 @@ public class FormatData_ce extends ListResourceBundle {
                     "\u0448",
                 }
             },
-            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.QuarterNames", metaValue_QuarterNames },
-            { "islamic.DayNarrows", metaValue_DayAbbreviations },
+            { "generic.DateTimePatterns",
+                new String[] {
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
+            { "standalone.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "roc.QuarterNames", metaValue_generic_QuarterNames },
+            { "islamic.DayNarrows", metaValue_generic_DayAbbreviations },
+            { "generic.QuarterNarrows", metaValue_generic_QuarterNarrows },
             { "field.zone", "\u0441\u0430\u0445\u044c\u0442\u0430\u043d \u0430\u0441\u0430" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "generic.DayNarrows", metaValue_generic_DayAbbreviations },
+            { "japanese.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "narrow.Eras", metaValue_Eras },
             { "calendarname.japanese", "\u044f\u043f\u043e\u043d\u0438\u0439\u043d" },
             { "Eras", metaValue_Eras },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.DayNames", metaValue_DayNames },
-            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
+            { "roc.DayNames", metaValue_generic_DayNames },
+            { "standalone.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "islamic.QuarterNames", metaValue_generic_QuarterNames },
             { "long.Eras",
                 new String[] {
                     "\u04c0\u0438\u0439\u0441\u0430 \u043f\u0430\u0439\u0445\u0430\u043c\u0430\u0440 \u0432\u0438\u043d\u0430 \u0434\u0435 \u043a\u0445\u0430\u0447\u0430\u043b\u0435",
                     "\u04c0\u0438\u0439\u0441\u0430 \u043f\u0430\u0439\u0445\u0430\u043c\u0430\u0440 \u0432\u0438\u043d\u0430 \u0434\u0438\u0439\u043d\u0430\u0445\u044c \u0434\u0443\u044c\u0439\u043d\u0430",
                 }
             },
-            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "islamic.DayNames", metaValue_DayNames },
+            { "roc.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "islamic.DayNames", metaValue_generic_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "field.weekday", "\u043a\u04c0\u0438\u0440\u0430\u043d\u0430\u043d \u0434\u0435" },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -211,31 +221,33 @@ public class FormatData_ce extends ListResourceBundle {
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
+            { "buddhist.DayNames", metaValue_generic_DayNames },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u043c\u0438\u043d\u043e\u0442" },
             { "field.era", "\u043c\u0443\u0440" },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "generic.DayNames", metaValue_generic_DayNames },
+            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "field.dayperiod", "\u0434\u0435\u043b\u043a\u044a\u0430\u043b \u0442\u04c0\u0435\u0445\u044c\u0430" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNames", metaValue_DayNames },
+            { "japanese.QuarterNames", metaValue_generic_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "japanese.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "roc.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "japanese.DayNames", metaValue_generic_DayNames },
+            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "DayNames", metaValue_generic_DayNames },
             { "field.month", "\u0431\u0443\u0442\u0442" },
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
             { "roc.MonthNames", metaValue_MonthNames },
             { "field.week", "\u043a\u04c0\u0438\u0440\u0430" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayAbbreviations },
+            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "DayNarrows", metaValue_generic_DayAbbreviations },
+            { "buddhist.QuarterNames", metaValue_generic_QuarterNames },
+            { "islamic.QuarterNarrows", metaValue_generic_QuarterNarrows },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
-            { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "calendarname.islamic", "\u0438\u0441\u043b\u0430\u043c\u0430\u043d" },
-            { "roc.DayNarrows", metaValue_DayAbbreviations },
+            { "roc.DayNarrows", metaValue_generic_DayAbbreviations },
+            { "generic.QuarterNames", metaValue_generic_QuarterNames },
             { "short.CompactNumberPatterns",
                 new String[] {
                     "",
@@ -256,11 +268,13 @@ public class FormatData_ce extends ListResourceBundle {
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
+            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "standalone.DayNames", metaValue_generic_DayNames },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames", metaValue_DayNames },
             { "PluralRules", "one:n = 1" },
             { "field.hour", "\u0441\u0430\u0445\u044c\u0442" },
+            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "generic.QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "latn.NumberPatterns",
@@ -290,12 +304,12 @@ public class FormatData_ce extends ListResourceBundle {
                     "{one:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
                 }
             },
-            { "buddhist.DayNarrows", metaValue_DayAbbreviations },
-            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
-            { "japanese.DayNarrows", metaValue_DayAbbreviations },
-            { "QuarterNames", metaValue_QuarterNames },
-            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "standalone.QuarterNames", metaValue_QuarterNames },
+            { "buddhist.DayNarrows", metaValue_generic_DayAbbreviations },
+            { "buddhist.QuarterNarrows", metaValue_generic_QuarterNarrows },
+            { "japanese.DayNarrows", metaValue_generic_DayAbbreviations },
+            { "QuarterNames", metaValue_generic_QuarterNames },
+            { "QuarterAbbreviations", metaValue_generic_QuarterAbbreviations },
+            { "standalone.QuarterNames", metaValue_generic_QuarterNames },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
