@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,19 +67,152 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
             { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
             { "JPY", "\u00a5" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
             { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
             { "PES", "PES" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
             { "RUB", "\u20bd" },
             { "RUR", "\u0440." },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
             { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJS", "TJS" },
             { "TMT", "\u0422\u041c\u0422" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
             { "UAH", "\u20b4" },
+            { "UGX", "UGX" },
             { "USD", "$" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
             { "VES", "VES" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
             { "XXX", "XXXX" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "adp", "\u0410\u043d\u0434\u043e\u0440\u0440\u0441\u043a\u0430\u044f \u043f\u0435\u0441\u0435\u0442\u0430" },
             { "aed", "\u0434\u0438\u0440\u0445\u0430\u043c \u041e\u0410\u042d" },
             { "afa", "\u0410\u0444\u0433\u0430\u043d\u0438 (1927\u20132002)" },
@@ -218,7 +347,7 @@ public class CurrencyNames_ru extends OpenListResourceBundle {
             { "lbp", "\u043b\u0438\u0432\u0430\u043d\u0441\u043a\u0438\u0439 \u0444\u0443\u043d\u0442" },
             { "lkr", "\u0448\u0440\u0438-\u043b\u0430\u043d\u043a\u0438\u0439\u0441\u043a\u0430\u044f \u0440\u0443\u043f\u0438\u044f" },
             { "lrd", "\u043b\u0438\u0431\u0435\u0440\u0438\u0439\u0441\u043a\u0438\u0439 \u0434\u043e\u043b\u043b\u0430\u0440" },
-            { "lsl", "\u041b\u043e\u0442\u0438" },
+            { "lsl", "\u043b\u043e\u0442\u0438" },
             { "ltl", "\u041b\u0438\u0442\u043e\u0432\u0441\u043a\u0438\u0439 \u043b\u0438\u0442" },
             { "ltt", "\u041b\u0438\u0442\u043e\u0432\u0441\u043a\u0438\u0439 \u0442\u0430\u043b\u043e\u043d" },
             { "luc", "\u041a\u043e\u043d\u0432\u0435\u0440\u0442\u0438\u0440\u0443\u0435\u043c\u044b\u0439 \u0444\u0440\u0430\u043d\u043a \u041b\u044e\u043a\u0441\u0435\u043c\u0431\u0443\u0440\u0433\u0430" },
