@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -70,11 +70,9 @@ public class LocaleNames_brx extends OpenListResourceBundle {
         final String metaValue_TO = "\u091f\u0949\u0902\u0917\u093e";
         final String metaValue_TR = "\u0924\u0941\u0930\u094d\u0915\u0940";
         final String metaValue_ae = "\u0905\u0935\u0938\u094d\u0924\u0928\u094d";
-        final String metaValue_ar = "\u0905\u0930\u092c\u0940";
         final String metaValue_bo = "\u0924\u093f\u092c\u094d\u092c\u0924\u0940";
         final String metaValue_el = "\u0917\u094d\u0930\u0940\u0915";
         final String metaValue_gu = "\u0917\u0941\u091c\u0930\u093e\u0924\u0940";
-        final String metaValue_ja = "\u091c\u093e\u092a\u093e\u0928\u0940";
         final String metaValue_jv = "\u091c\u093e\u0935\u093e\u0928\u0940\u0938";
         final String metaValue_km = "\u0916\u094d\u092e\u0947\u0930";
         final String metaValue_or = "\u0909\u0921\u093c\u093f\u092f\u093e";
@@ -114,7 +112,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "AT", "\u0911\u0938\u094d\u091f\u094d\u0930\u093f\u092f\u093e" },
             { "AU", "\u0911\u0938\u094d\u091f\u094d\u0930\u0947\u0932\u093f\u092f\u093e" },
             { "AW", "\u0905\u0930\u0942\u092c\u093e" },
-            { "en_US", "\u0905\u0902\u0917\u094d\u0930\u0947\u091c\u093c\u0940 (\u0905\u092e\u0930\u093f\u0915\u0940)" },
+            { "en_US", "\u0906\u092e\u0947\u0930\u093f\u0915\u093e\u0928\u093f \u0907\u0902\u0930\u093e\u091c\u0940" },
             { "AX", "\u0906\u0932\u093e\u0901\u0921 \u0926\u094d\u0935\u0940\u092a" },
             { "AZ", "\u0905\u091c\u093c\u0930\u092c\u0948\u091c\u093e\u0928" },
             { "%%AREVELA", "\u092a\u0942\u0930\u094d\u0935\u0940 \u0905\u0930\u094d\u092e\u0947\u0928\u093f\u092f\u093e\u0908" },
@@ -136,7 +134,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "myv", "\u0910\u0930\u094d\u091c\u093c\u093f\u092f\u093e" },
             { "BN", "\u092c\u094d\u0930\u0942\u0928\u0907" },
             { "BO", "\u092c\u094b\u0932\u0940\u0935\u093f\u092f\u093e" },
-            { "BR", "\u092c\u094d\u0930\u093e\u091c\u093c\u0940\u0932" },
+            { "BR", "\u092c\u094d\u0930\u093e\u091c\u0940\u0932" },
             { "BS", "\u092c\u0939\u093e\u092e\u093e" },
             { "BT", "\u092d\u0942\u091f\u093e\u0928" },
             { "BV", "\u092c\u0941\u0935\u0947 \u0926\u094d\u0935\u0940\u092a" },
@@ -154,7 +152,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "CK", "\u0915\u0941\u0915 \u0926\u094d\u0935\u0940\u092a" },
             { "CL", "\u091a\u093f\u0932\u0940" },
             { "CM", "\u0915\u094b\u092e\u0947\u0930\u093e\u0928" },
-            { "CN", "\u091a\u0940\u0928" },
+            { "CN", "\u091a\u093e\u0907\u0928\u093e" },
             { "CO", "\u0915\u094b\u0932\u092e\u094d\u092c\u093f\u092f\u093e" },
             { "CR", "\u0915\u094b\u0938\u094d\u091f\u093e\u0930\u0940\u0915\u093e" },
             { "CU", "\u0915\u094d\u092f\u0942\u092c\u093e" },
@@ -163,9 +161,10 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "CY", "\u0938\u093e\u0907\u092a\u094d\u0930\u0938" },
             { "CZ", "\u091a\u0947\u0915 \u0917\u0923\u0930\u093e\u091c\u094d\u092f" },
             { "eka", "\u090f\u0915\u093e\u091c\u0941\u0915" },
-            { "DE", "\u091c\u0930\u094d\u092e\u0928\u0940" },
+            { "DE", "\u091c\u093e\u0930\u094d\u092e\u093e\u0928\u0940" },
             { "goh", "\u092a\u0941\u0930\u093e\u0928\u0940 \u0909\u091a\u094d\u091a\u0938\u094d\u0924\u0930\u0940 \u091c\u0930\u094d\u092e\u0928" },
             { "ace", "\u0905\u091a\u0947\u0939\u0928\u0940" },
+            { "type.nu.deva", "\u0926\u0947\u092c\u0928\u093e\u0917\u093f\u0930\u093f \u0905\u0928\u091c\u093f\u092e\u093e\u092b\u094b\u0930" },
             { "DJ", "\u0926\u094d\u091c\u093f\u092c\u0942\u0924\u0940" },
             { "DK", "\u0921\u0947\u0928\u092e\u093e\u0930\u094d\u0915" },
             { "ach", "\u0905\u0915\u094b\u0932\u0940" },
@@ -204,7 +203,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "ET", "\u0907\u0925\u093f\u0913\u092a\u093f\u092f\u093e" },
             { "EU", "\u092f\u0942\u0930\u094b\u092a\u0940\u092f \u0938\u0902\u0918" },
             { "elx", "\u090f\u0932\u093e\u092e\u0940" },
-            { "type.ca.gregorian", "\u0917\u094d\u0930\u0947\u0917\u0930\u0940\u0905\u0928 \u092a\u0902\u091a\u093e\u0902\u0917" },
+            { "type.ca.gregorian", "\u0917\u094d\u0930\u0947\u0917\u2019\u0930\u093f\u092f\u093e\u0928 \u0915\u0947\u0932\u0947\u0923\u094d\u0921\u093e\u0930" },
             { "chy", "\u0936\u093e\u092f\u093e\u0928\u094d" },
             { "Inds", "\u0938\u093f\u0928\u094d\u0927\u0941" },
             { "ady", "\u0905\u0921\u0940\u0917\u0947" },
@@ -214,14 +213,13 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "FM", "\u092e\u093e\u0907\u0915\u094d\u0930\u094b\u0928\u0947\u0936\u093f\u092f\u093e" },
             { "FO", "\u092b\u0930\u094b \u0926\u094d\u0935\u0940\u092a" },
             { "Taml", "\u0924\u092e\u0940\u0933" },
-            { "FR", "\u092b\u094d\u0930\u093e\u0901\u0938" },
+            { "FR", "\u092b\u094d\u0930\u093e\u0928\u094d\u0938" },
             { "tkl", metaValue_TK },
             { "grb", "\u0917\u094d\u0930\u0947\u092c\u094b" },
-            { "root", "\u0930\u0941\u091f" },
             { "grc", "\u092a\u094d\u0930\u093e\u091a\u0940\u0928 \u092f\u0942\u0928\u093e\u0928\u0940" },
             { "GA", "\u0917\u0948\u092c\u0949\u0928" },
             { "vot", "\u0935\u094b\u091f\u0940\u0915" },
-            { "GB", "\u092c\u094d\u0930\u093f\u0924\u0928" },
+            { "GB", "\u091c\u0925\u093e\u092f \u092c\u094d\u0930\u093f\u091f\u093f\u0936 \u0939\u093e\u0926\u094b\u0930" },
             { "GD", "\u0917\u094d\u0930\u0947\u0928\u0921\u093e" },
             { "GE", "\u091c\u0949\u0930\u094d\u091c\u093f\u092f\u093e" },
             { "GF", "\u092b\u094d\u0930\u093e\u0901\u0938\u0940\u0938\u0940 \u0917\u093f\u0906\u0928\u093e" },
@@ -246,7 +244,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "Talu", "\u0928\u092f\u093e \u0924\u093e\u0908 \u0932\u0941\u090f" },
             { "GY", "\u0917\u0941\u092f\u093e\u0928\u093e" },
             { "zxx", "\u0930\u093f\u0915\u094d\u0924" },
-            { "de_AT", "\u091c\u0930\u094d\u092e\u0928 (\u0911\u0938\u094d\u091f\u094d\u0930\u093f\u092f\u093e)" },
+            { "de_AT", "\u0905\u0938\u094d\u091f\u094d\u0930\u0947\u092f\u093e\u0906\u0930\u093f \u091c\u093e\u0930\u094d\u092e\u093e\u0928" },
             { "Vaii", metaValue_vai },
             { "HK", "\u0939\u093e\u0901\u0917\u0915\u093e\u0901\u0917 \u0935\u093f\u0936\u0947\u0937 \u092a\u094d\u0930\u0936\u093e\u0938\u0928\u093f\u0915 \u0915\u094d\u0937\u0947\u0924\u094d\u0930 \u091a\u0940\u0928" },
             { "HM", "\u0939\u0930\u094d\u0921 \u0926\u094d\u0935\u0940\u092a \u090f\u0935\u0902 \u092e\u0948\u0915\u0921\u094b\u0928\u0949\u0932\u094d\u0921 \u0926\u094d\u0935\u0940\u092a" },
@@ -268,7 +266,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "IQ", "\u0908\u0930\u093e\u0915\u093c" },
             { "IR", "\u0908\u0930\u093e\u0928" },
             { "IS", "\u0906\u0907\u0938\u0932\u0948\u0902\u0921" },
-            { "IT", "\u0907\u091f\u0932\u0940" },
+            { "IT", "\u0907\u091f\u093e\u0932\u0940" },
             { "%%POSIX", "\u0915\u092e\u094d\u092a\u094d\u092f\u0942\u091f\u0930" },
             { "JE", "\u091c\u0930\u094d\u0938\u0940" },
             { "type.ca.islamic", "\u0907\u0938\u094d\u0932\u093e\u092e\u0940 \u092a\u0902\u091a\u093e\u0902\u0917" },
@@ -280,7 +278,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "ain", "\u0910\u0928\u0942" },
             { "tog", "\u0928\u094d\u092f\u093e\u0938\u093e \u091f\u0949\u0902\u0917\u093e" },
             { "Kali", "\u0915\u093e\u092f\u093e\u0939 \u0932\u0940" },
-            { "de_CH", "\u0909\u091a\u094d\u091a \u0938\u094d\u0924\u0930\u093f\u092f \u0938\u094d\u0935\u0940\u0938 \u091c\u0930\u094d\u092e\u0928" },
+            { "de_CH", "\u0938\u0941\u0907\u0938 \u0917\u094b\u091c\u094c \u091c\u093e\u0930\u094d\u092e\u093e\u0928" },
             { "type.ca.buddhist", "\u092c\u094c\u0926\u094d\u0927 \u092a\u0902\u091a\u093e\u0902\u0917" },
             { "KE", "\u0915\u0947\u0928\u094d\u092f\u093e" },
             { "419", "\u0932\u0948\u091f\u093f\u0928 \u0905\u092e\u0930\u093f\u0915\u093e \u090f\u0935\u0902 \u0915\u0930\u0940\u092c\u0940" },
@@ -291,16 +289,16 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "KN", "\u0938\u0947\u0902\u091f \u0915\u093f\u091f\u094d\u0938 \u090f\u0935\u0902 \u0928\u0947\u0935\u093f\u0938" },
             { "Knda", "\u0915\u0928\u094d\u0928\u0921\u093c" },
             { "Zinh", "\u0935\u093f\u0930\u093e\u0938\u0924" },
-            { "fr_CA", "\u092b\u094d\u0930\u093e\u0902\u0938\u0940\u0938\u0940 (\u0915\u0928\u093e\u0921\u093e\u0908)" },
+            { "fr_CA", "\u0915\u093e\u0928\u093e\u0921\u093e\u0928\u093f \u092b\u094d\u0930\u0947\u0928\u094d\u091a" },
             { "KP", "\u0909\u0924\u094d\u0924\u0930 \u0915\u094b\u0930\u093f\u092f\u093e" },
             { "KR", "\u0926\u0915\u094d\u0937\u093f\u0923 \u0915\u094b\u0930\u093f\u092f\u093e" },
             { "Plrd", "\u092a\u094c\u0932\u093e\u0930\u094d\u0921\u093c \u092b\u094b\u0928\u0947\u091f\u0940\u0915" },
-            { "fr_CH", "\u092b\u094d\u0930\u093e\u0902\u0938\u0940\u0938\u0940 (\u0938\u094d\u0935\u0940\u0938)" },
+            { "fr_CH", "\u0938\u0941\u0907\u0938 \u092b\u094d\u0930\u0947\u0928\u094d\u091a" },
             { "KW", "\u0915\u0941\u0935\u0948\u0924" },
             { "tpi", "\u0924\u094b\u0915 \u092a\u093f\u0938\u0940\u0928" },
             { "KY", "\u0915\u0947\u092e\u0948\u0928 \u0926\u094d\u0935\u0940\u092a" },
             { "KZ", "\u0915\u091c\u093c\u093e\u0916\u0938\u094d\u0924\u093e\u0928" },
-            { "Cyrl", "\u0938\u093f\u0930\u093f\u0932\u093f\u0915\u094d" },
+            { "Cyrl", "\u0938\u093f\u0930\u093f\u0932\u094d\u0932\u093f\u0915" },
             { "LA", "\u0932\u093e\u0913\u0938" },
             { "LB", "\u0932\u0947\u092c\u0928\u094b\u0928" },
             { "LC", "\u0938\u0947\u0902\u091f \u0932\u0942\u0938\u093f\u092f\u093e" },
@@ -376,7 +374,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "PA", "\u092a\u0928\u093e\u092e\u093e" },
             { "type.ca.islamic-civil", "\u0907\u0938\u094d\u0932\u093e\u092e\u0940 \u0928\u093e\u0917\u0930\u093f\u0915 \u092a\u0902\u091a\u093e\u0902\u0917" },
             { "csb", "\u0915\u093e\u0936\u0941\u092c\u093f\u092f\u093e\u0928\u094d" },
-            { "en_GB", "\u0905\u0902\u0917\u094d\u0930\u0947\u091c\u0940 (\u092c\u094d\u0930\u093f\u091f\u093f\u0936)" },
+            { "en_GB", "\u092c\u094d\u0930\u093f\u091f\u093f\u0936 \u0907\u0902\u0930\u093e\u091c\u0940" },
             { "PE", "\u092a\u0947\u0930\u0942" },
             { "PF", "\u092b\u094d\u0930\u093e\u0901\u0938\u0940\u0938\u0940 \u092a\u0949\u0932\u093f\u0928\u0940\u0936\u093f\u092f\u093e" },
             { "PG", "\u092a\u093e\u092a\u0941\u0906 \u0928\u094d\u092f\u0942 \u0917\u093f\u0928\u0940" },
@@ -412,7 +410,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "009", "\u0913\u0936\u0947\u0906\u0928\u093f\u092f\u093e" },
             { "RO", "\u0930\u094b\u092e\u093e\u0928\u093f\u092f\u093e" },
             { "RS", "\u0938\u0930\u094d\u092c\u093f\u092f\u093e" },
-            { "RU", "\u0930\u0942\u0938" },
+            { "RU", "\u0930\u093e\u0938\u093f\u092f\u093e" },
             { "RW", "\u0930\u0942\u0906\u0923\u094d\u0921\u093e" },
             { "Mani", "\u092e\u093e\u0928\u0940\u0915\u0940" },
             { "Ugar", "\u090a\u0917\u093e\u0930\u0940\u091f\u0940\u0915" },
@@ -470,7 +468,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "TW", "\u0924\u093e\u0907\u0935\u093e\u0928" },
             { "Orkh", "\u0913\u0930\u0916\u094b\u0928" },
             { "TZ", "\u0924\u0902\u091c\u093c\u093e\u0928\u093f\u092f\u093e" },
-            { "Zzzz", "\u0905\u091c\u094d\u091e\u093e\u0924 \u092f\u093e \u0905\u0935\u0948\u0927 \u0932\u093f\u092a\u093f" },
+            { "Zzzz", "\u092e\u093f\u0925\u093f\u092f\u0948 \u0939\u093e\u0902\u0916\u094b" },
             { "UA", "\u092f\u0942\u0915\u094d\u0930\u0947\u0928" },
             { "rup", "\u0906\u0930\u094b\u092e\u093e\u0928\u0940" },
             { "030", "\u092a\u0942\u0930\u094d\u0935\u0940 \u090f\u0936\u093f\u092f\u093e" },
@@ -483,7 +481,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "039", "\u0926\u0915\u094d\u0937\u093f\u0923\u0940 \u092f\u0942\u0930\u094b\u092a" },
             { "Sinh", "\u0938\u093f\u0902\u0939\u093e\u0932\u0940" },
             { "UM", "\u092f\u0941\u0928\u093e\u0907\u091f\u0947\u0921 \u0938\u094d\u091f\u0947\u091f\u094d\u0938 \u0915\u0947 \u091b\u094b\u091f\u0947 \u092c\u093e\u0939\u0930\u093f\u092f \u0926\u094d\u0935\u0940\u092a" },
-            { "US", "\u0938\u0902\u092f\u0941\u0915\u094d\u0924 \u0930\u093e\u091c\u094d\u092f \u0905\u092e\u0930\u093f\u0915\u093e" },
+            { "US", "\u091c\u0925\u093e\u092f \u0939\u093e\u0926\u094b\u0930 \u0906\u092e\u0947\u0930\u093f\u0915\u093e" },
             { "haw", "\u0939\u0935\u093e\u0908\u0905\u0928" },
             { "type.co.gb2312han", "\u0938\u0930\u0932\u0940\u0915\u0943\u0924 \u091a\u0940\u0928\u0940 \u0935\u0930\u094d\u0917\u0940\u0915\u0930\u0923 \u091c\u0940\u092c\u09402312" },
             { "UY", "\u092f\u0941\u0930\u0942\u0917\u0941\u090f" },
@@ -511,23 +509,24 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "awa", "\u0905\u0935\u0927\u0940" },
             { "061", "\u092a\u094b\u0932\u0940\u0928\u0947\u0936\u093f\u092f\u093e" },
             { "Gujr", metaValue_gu },
-            { "Zxxx", "\u0905\u0932\u093f\u0916\u093f\u0924" },
+            { "Zxxx", "\u0932\u093f\u0930\u0948" },
             { "Olck", "\u0913\u0932 \u091a\u0940\u0915\u0940" },
             { "Batk", "\u092c\u091f\u0915\u0940" },
             { "Blis", "\u092c\u094d\u0932\u0940\u0938 \u091a\u0940\u0928\u094d\u0939" },
             { "YE", "\u092f\u092e\u0928" },
             { "nqo", metaValue_nqo },
+            { "type.co.standard", "\u0925\u093e\u0916\u094b\u0906\u0930\u093f \u0930\u094b\u0916\u094b\u092e \u092b\u093e\u0930\u093f" },
             { "fan", "\u092b\u093e\u0901\u0917\u094d" },
             { "%%ROZAJ", "\u0930\u0947\u091c\u093c\u0940\u092f\u0928" },
             { "fat", "\u092b\u093e\u0901\u091f\u0940" },
             { "Sgnw", "\u0938\u093e\u0902\u0915\u0947\u0924\u093f\u0915 \u0932\u0947\u0916" },
             { "YT", "\u092e\u0948\u092f\u094c\u091f" },
             { "ZA", "\u0926\u0915\u094d\u0937\u093f\u0923 \u0905\u092b\u094d\u0930\u0940\u0915\u093e" },
-            { "Deva", "\u0926\u0947\u0935\u0928\u093e\u0917\u0930\u0940" },
+            { "Deva", "\u0926\u0947\u092c\u0928\u093e\u0917\u093f\u0930\u093f" },
             { "Hira", "\u0939\u0940\u0930\u093e\u0917\u093e\u0928\u093e" },
             { "ZM", "\u091c\u093c\u093e\u092e\u094d\u092c\u093f\u092f\u093e" },
             { "ZW", "\u091c\u093c\u0940\u092e\u094d\u092c\u093e\u092c\u094d\u0935\u0947" },
-            { "ZZ", "\u0905\u091c\u094d\u091e\u093e\u0924 \u092f\u093e \u0905\u0935\u0948\u0927 \u092a\u094d\u0930\u0926\u0947\u0936" },
+            { "ZZ", "\u092e\u093f\u0925\u093f\u092f\u0948 \u0913\u0928\u0938\u094b\u0932" },
             { "Runr", "\u0930\u0942\u0928\u093f\u0915" },
             { "lol", "\u092e\u094b\u0902\u0917\u094b" },
             { "loz", "\u0932\u094b\u091c\u093c\u0940" },
@@ -567,7 +566,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "uga", "\u0909\u0917\u093e\u0930\u093f\u0924\u0940" },
             { "bas", "\u092c\u093e\u0938\u094d\u0915\u093c\u094d" },
             { "jrb", "\u092f\u0939\u0941\u0926\u0940 \u0905\u0930\u092c\u0940" },
-            { "es_ES", "\u0908\u0935\u0947\u0930\u093f\u092f\u093e\u0908 \u0938\u094d\u092a\u0948\u0928\u093f\u0936" },
+            { "es_ES", "\u092f\u0941\u0930\u094b\u092a\u0928\u093f \u0938\u094d\u092a\u0947\u0928\u093f\u0936" },
             { "nzi", "\u0928\u094d\u091c\u093c\u0940\u092e\u093e" },
             { "sco", "\u0938\u094d\u0915\u0949\u091f" },
             { "scn", "\u0938\u0940\u0938\u0940\u0932\u0940\u0905\u0928" },
@@ -576,11 +575,11 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "af", "\u0905\u092b\u094d\u0930\u0940\u0915\u0940" },
             { "ak", "\u0905\u0915\u0928" },
             { "am", "\u0905\u092e\u094d\u0939\u093e\u0930\u093f\u0915\u094d" },
-            { "Arab", metaValue_ar },
             { "an", "\u0906\u0930\u094d\u0917\u094b\u0928\u0940" },
+            { "Arab", "\u0906\u0930\u093e\u092c\u093f\u0915" },
             { "%%SOLBA", "\u0936\u094d\u091f\u094b\u0932\u0935\u093f\u091c\u093c\u094d\u091c\u093c\u093e \u092f\u093e \u0938\u094b\u0932\u092c\u0940\u0915\u093e \u0921\u093e\u092f\u0932\u0947\u0915\u094d\u091f" },
-            { "Jpan", metaValue_ja },
-            { "ar", metaValue_ar },
+            { "Jpan", "\u091c\u093e\u092a\u093e\u0928\u0940" },
+            { "ar", "\u0905\u0930\u092c\u0940" },
             { "Hrkt", "\u0915\u093e\u0924\u093e\u0915\u093e\u0928\u093e \u092f\u093e \u0939\u0940\u0930\u093e\u0917\u093e\u0928\u093e" },
             { "as", "\u0905\u0938\u093e\u092e\u0940" },
             { "Lina", "\u0932\u0940\u0928\u0940\u092f\u0930 \u090f" },
@@ -615,23 +614,24 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "cy", "\u0935\u0948\u0932\u094d\u0936\u094d" },
             { "Yiii", "\u092f\u0940" },
             { "da", "\u0921\u0948\u0928\u0940\u0936\u094d" },
-            { "de", "\u091c\u093c\u0930\u094d\u092e\u0928" },
+            { "pt_PT", "\u092f\u0941\u0930\u094b\u092a\u0928\u093f \u092a\u0930\u094d\u091f\u0941\u0917\u093f\u091c" },
+            { "de", "\u091c\u093e\u0930\u094d\u092e\u093e\u0928" },
             { "bej", "\u092c\u0947\u091c\u093e" },
             { "din", "\u0921\u0940\u0902\u0917\u0915\u093e" },
             { "Bugi", metaValue_bug },
             { "bem", "\u092c\u0947\u0902\u092c\u093e" },
             { "sga", "\u092a\u0941\u0930\u093e\u0928\u0940 \u0906\u0908\u0930\u0940\u0936" },
             { "dv", "\u0926\u0940\u0935\u0947\u0939\u0940" },
-            { "es_419", "\u0932\u0948\u091f\u093f\u0928 \u0905\u092e\u0930\u093f\u0915\u0940 \u0938\u094d\u092a\u0948\u0928\u093f\u0936" },
+            { "es_419", "\u0932\u0947\u091f\u0940\u0928 \u0906\u092e\u0947\u0930\u093f\u0915\u093e\u0928\u093f \u0938\u094d\u092a\u0947\u0928\u093f\u0936" },
             { "dz", "\u092d\u0941\u091f\u093e\u0928\u0940" },
             { "type.ca.chinese", "\u091a\u0940\u0928\u0940 \u092a\u0902\u091a\u093e\u0902\u0917" },
             { "ee", "\u090f\u0935\u0947" },
             { "ro_MD", "\u092e\u094b\u0932\u094d\u0921\u0947\u0935\u093f\u092f\u0928\u094d" },
             { "el", metaValue_el },
-            { "en", "\u0905\u0902\u0917\u094d\u0930\u0947\u091c\u093c\u0940" },
+            { "en", "\u0907\u0902\u0930\u093e\u091c\u0940" },
             { "eo", "\u090f\u0938\u094d\u092a\u0947\u0930\u093e\u0928\u094d\u0924\u094b" },
             { "type.co.big5han", "\u092a\u093e\u0930\u092e\u094d\u092a\u093e\u0930\u093f\u0915 \u091a\u0940\u0928\u0940 \u0935\u0930\u094d\u0917\u0940\u0915\u0930\u0923 \u092c\u0940\u0917 \u092b\u093c\u093e\u0908\u0935" },
-            { "es", "\u0938\u094d\u092a\u0948\u0928\u093f\u0936" },
+            { "es", "\u0938\u094d\u092a\u0947\u0928\u093f\u0936" },
             { "et", "\u0910\u0938\u094d\u091f\u094b\u0928\u093f\u092f\u0928\u094d" },
             { "eu", "\u092c\u093e\u0938\u094d\u0915\u094d" },
             { "Buhd", "\u092c\u0941\u0939\u0940\u0926" },
@@ -642,15 +642,16 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "shn", "\u0936\u093e\u0928" },
             { "Hano", "\u0939\u093e\u0928\u0941\u0928\u0941" },
             { "fa", "\u092b\u093e\u0930\u094d\u0938\u0940" },
-            { "Hans", "\u0938\u0930\u0932\u0940\u0915\u0943\u0924 \u0939\u093e\u0928" },
-            { "Hant", "\u092a\u093e\u0930\u092e\u094d\u092a\u0930\u093f\u0915 \u0939\u093e\u0928" },
+            { "Hans", "\u0917\u094b\u0930\u0932\u0948 \u0916\u093e\u0932\u093e\u092e\u0928\u093e \u0939\u094b\u0928\u093e\u092f" },
+            { "type.nu.latn", "\u0938\u094b\u0928\u093e\u092c\u093e\u0930\u0940 \u0905\u0928\u091c\u093f\u092e\u093e\u092b\u094b\u0930" },
+            { "Hant", "\u0906\u0938\u093e\u0930-\u0916\u093e\u0928\u094d\u0925\u093f\u0928\u093f" },
             { "ff", "\u092b\u0941\u0932\u093e\u0939\u094d" },
             { "fi", "\u092b\u093f\u0928\u093f\u0936\u094d" },
             { "fj", "\u092b\u093c\u0940\u091c\u0940" },
             { "fon", "\u092b\u094b\u0928" },
             { "fo", "\u092b\u093f\u0930\u094b\u091c\u093c\u0940" },
             { "umb", "\u0909\u0902\u092c\u0941\u0902\u0921\u0941" },
-            { "fr", "\u092b\u094d\u0930\u093e\u0902\u0938\u0940\u0938\u0940" },
+            { "fr", "\u092b\u094d\u0930\u0947\u0928\u094d\u091a" },
             { "sid", "\u0938\u0940\u0926\u093e\u092e\u094b" },
             { "fy", "\u092a\u0936\u094d\u091a\u0940\u092e\u0940 \u092b\u094d\u0930\u0940\u091c\u093c\u093f\u092f\u0928\u094d" },
             { "ga", "\u0906\u0908\u0930\u093f\u0936" },
@@ -658,7 +659,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "gl", "\u0917\u0948\u0932\u093f\u0936\u093f\u092f\u0928\u094d" },
             { "gn", "\u0917\u0941\u0906\u0930\u093e\u0928\u0940" },
             { "bho", "\u092d\u094b\u091c\u092a\u0941\u0930\u0940" },
-            { "und", "\u0905\u091c\u094d\u091e\u093e\u0924 \u092f\u093e \u0905\u0935\u0948\u0927 \u092d\u093e\u0937\u093e" },
+            { "und", "\u092e\u093f\u0925\u093f\u092f\u0948 \u0930\u093e\u0935" },
             { "gu", metaValue_gu },
             { "gv", "\u092e\u0948\u0902\u0915\u094d\u0938" },
             { "ha", "\u0939\u0909\u0938\u093e" },
@@ -686,9 +687,9 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "frs", "\u092a\u0942\u0930\u094d\u0935\u0940 \u092b\u094d\u0930\u0940\u091c\u093c\u093f\u092f\u0928\u094d" },
             { "frr", "\u0909\u0924\u094d\u0924\u0930\u0940 \u092b\u094d\u0930\u0940\u091c\u093c\u093f\u092f\u0928\u094d" },
             { "is", "\u0906\u0908\u0938\u094d\u0932\u0948\u0902\u0921\u093f\u0915\u094d" },
-            { "it", "\u0908\u091f\u093e\u0932\u093f\u092f\u0928\u094d" },
+            { "it", "\u0907\u091f\u093e\u0932\u093f\u092f\u093e\u0928" },
             { "iu", "\u0907\u0928\u0942\u0915\u094d\u091f\u0940\u091f\u0942\u0924\u094d" },
-            { "ja", metaValue_ja },
+            { "ja", "\u091c\u093e\u092a\u093e\u0928\u0940\u091c" },
             { "Mlym", "\u092e\u0932\u092f\u093e\u0932\u092e\u094d" },
             { "Sara", "\u0938\u0930\u093e\u0924\u0940" },
             { "doi", "\u0921\u094b\u0917\u0930\u0940" },
@@ -789,16 +790,17 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "pl", "\u092a\u094b\u0932\u093f\u0936" },
             { "dum", "\u092e\u0927\u094d\u092f \u0921\u091a" },
             { "ps", "\u092a\u0916\u093c\u094d\u0924\u0941" },
-            { "pt", "\u092a\u0941\u0930\u094d\u0924\u0917\u093e\u0932\u0940" },
+            { "pt", "\u092a\u0930\u094d\u091f\u0941\u0917\u093f\u091c" },
             { "mga", "\u092e\u0927\u094d\u092f \u0906\u0908\u0930\u0940\u0936 \u092d\u093e\u0937\u093e" },
             { "key.co", "\u0935\u0930\u094d\u0917\u0940\u0915\u0930\u0923" },
+            { "pt_BR", "\u092c\u094d\u0930\u093e\u091c\u093f\u0932\u0928\u093f \u092a\u0930\u094d\u091f\u0941\u0917\u093f\u091c" },
             { "kcg", "\u0924\u094d\u092f\u093e\u092a\u094d" },
             { "bra", "\u092c\u094d\u0930\u091c" },
             { "key.ca", "\u092a\u0902\u091a\u093e\u0917" },
             { "Laoo", "\u0932\u093e\u0913" },
             { "qu", "\u0915\u094d\u0935\u0947\u091a\u0941\u0906" },
             { "zap", "\u091c\u093c\u093e\u092a\u094b\u0924\u0947\u0915" },
-            { "brx", "\u092c\u0921\u093c\u094b" },
+            { "brx", "\u092c\u0930\u2019" },
             { "Lana", "\u0932\u093e\u0928\u093e" },
             { "Ethi", "\u0908\u0925\u094b\u092a\u093f\u092f\u093e\u0908" },
             { "rm", "\u0930\u0947\u0939\u094d\u091f\u094b-\u0930\u094b\u092e\u093e\u0928\u094d\u0938" },
@@ -806,12 +808,12 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "key.cu", "\u092e\u0941\u0926\u094d\u0930\u093e" },
             { "ro", "\u0930\u0942\u092e\u093e\u0928\u0940\u092f\u0928\u094d" },
             { "%%SAAHO", "\u0938\u093e\u0939\u094b" },
-            { "ru", "\u0930\u0941\u0938\u0940" },
+            { "ru", "\u0930\u093e\u0938\u093f\u092f\u093e\u0928" },
             { "rw", "\u0915\u093f\u0928\u094d\u092f\u093e\u0930\u0941\u0906\u0923\u094d\u0921\u093e" },
             { "zbl", "\u092c\u094d\u0932\u0940\u0938 \u091a\u093f\u0928\u094d\u0939" },
             { "mic", "\u092e\u0940\u0915\u092e\u093e\u0915" },
             { "suk", "\u0938\u0941\u0915\u0941\u092e\u093e" },
-            { "en_AU", "\u0905\u0902\u0917\u094d\u0930\u0947\u091c\u093c\u0940 (\u0911\u0938\u094d\u091f\u094d\u0930\u0947\u0932\u093f\u092f\u093e \u0915\u093e)" },
+            { "en_AU", "\u0905\u0938\u094d\u091f\u094d\u0930\u0947\u0932\u093f\u092f\u093e\u0928\u093f \u0907\u0902\u0930\u093e\u091c\u0940" },
             { "sa", "\u0938\u0902\u0938\u094d\u0915\u0943\u0924\u094d" },
             { "sc", "\u0938\u093e\u0930\u094d\u0926\u0940\u0928\u0940" },
             { "sus", "\u0938\u0941\u0938\u0941" },
@@ -847,7 +849,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "bug", metaValue_bug },
             { "ti", "\u0924\u093f\u0917\u094d\u0930\u0940\u0928\u094d\u092f\u093e" },
             { "kfo", "\u0915\u094b\u0930\u094b" },
-            { "en_CA", "\u0905\u0902\u0917\u094d\u0930\u0947\u091c\u093c\u0940 (\u0915\u0928\u093e\u0921\u093e\u0908)" },
+            { "en_CA", "\u0915\u093e\u0928\u093e\u0921\u093e\u0928\u093f \u0907\u0902\u0930\u093e\u091c\u0940" },
             { "tk", "\u0924\u0941\u0930\u094d\u0915\u092e\u0947\u0928" },
             { "tl", "\u0924\u093e\u0917\u093e\u0932\u094b\u0917" },
             { "tn", "\u0924\u094d\u0938\u094d\u0935\u093e\u0928\u093e" },
@@ -898,7 +900,7 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "Latf", "\u092b\u094d\u0930\u0948\u0915\u094d\u0924\u0941\u0930 \u0932\u0948\u091f\u093f\u0928" },
             { "gba", "\u0917\u094d\u092c\u093e\u092f\u093e" },
             { "mni", "\u092e\u0923\u0940\u092a\u0941\u0930\u0940" },
-            { "Latn", "\u0932\u0948\u091f\u093f\u0928" },
+            { "Latn", "\u0932\u0947\u091f\u0940\u0928" },
             { "Latg", "\u0917\u0948\u0932\u0940\u0915 \u0932\u0948\u091f\u093f\u0928" },
             { "xh", "\u0916\u093c\u094b\u0938\u093e" },
             { "byn", "\u092c\u094d\u0932\u0940\u0928" },
@@ -911,13 +913,14 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "Syrc", "\u0938\u0940\u0930\u0940\u0906\u0915" },
             { "Dsrt", "\u0926\u0947\u0938\u0947\u0930\u091f\u094d" },
             { "yo", "\u092f\u094b\u0930\u0942\u092c\u093e" },
+            { "es_MX", "\u092e\u0947\u0915\u094d\u0938\u093f\u0915\u2019\u0928\u093f \u0938\u094d\u092a\u0947\u0928\u093f\u0936" },
             { "Syrj", "\u092a\u0936\u094d\u091a\u0940\u092e\u0940 \u0938\u0940\u0930\u0940\u0906\u0915" },
             { "ota", "\u0924\u0941\u0930\u094d\u0915\u0940 \u0913\u091f\u094b\u092e\u093e\u0928" },
             { "Syre", "\u090f\u0938\u094d\u091f\u094d\u0930\u093e\u0902\u0917\u0932\u094b \u0938\u0940\u0930\u0940\u0906\u0915" },
             { "vai", metaValue_vai },
             { "za", "\u091c\u093c\u0941\u0906\u0902\u0917" },
             { "Cari", "\u0915\u093e\u0930\u093f\u092f\u0928" },
-            { "zh", "\u091a\u0940\u0928\u0940" },
+            { "zh", "\u091a\u093e\u0907\u0928\u0940\u091c" },
             { "Bopo", "\u092c\u094b\u092a\u094b\u092e\u094b\u092b\u094b" },
             { "Perm", "\u092a\u0941\u0930\u093e\u0928\u0940 \u092a\u0930\u094d\u092e\u0940\u0915\u094d" },
             { "zu", "\u091c\u093c\u0941\u0932\u0942" },
@@ -933,12 +936,12 @@ public class LocaleNames_brx extends OpenListResourceBundle {
             { "Egyh", "\u092e\u0940\u0938\u094d\u0930\u0940 \u0939\u0948\u0930\u0948\u091f\u0940\u0915\u094d" },
             { "Egyp", "\u092e\u0940\u0938\u094d\u0930\u0940 \u0939\u0948\u0930\u094b\u0917\u094d\u0932\u0940\u092b\u093c\u094d" },
             { "Geok", "\u091c\u094b\u0930\u094d\u091c\u0940\u092f\u0928 \u0916\u0941\u0924\u0938\u0941\u0930\u0940" },
-            { "zh_Hans", "\u091a\u0940\u0928\u0940 (\u0938\u0930\u0932\u0940\u0915\u0943\u0924)" },
+            { "zh_Hans", "\u0917\u094b\u0930\u0932\u0948 \u0916\u093e\u0932\u093e\u092e\u0928\u093e\u092f \u091a\u093e\u0907\u0928\u0940\u091c" },
             { "Hung", "\u092a\u0941\u0930\u093e\u0928\u0940 \u0939\u0902\u0917\u0948\u0930\u0940\u092f\u0928" },
             { "kok", "\u0915\u094b\u0902\u0915\u0923\u0940" },
             { "%%1901", "\u092a\u093e\u0930\u092e\u094d\u092a\u093e\u0930\u093f\u0915 \u091c\u0930\u094d\u092e\u0928 \u0935\u0930\u094d\u0924\u0928\u0940 1901" },
             { "kos", "\u0915\u094b\u0938\u094d\u0930\u093e\u0908\u092f\u0928\u094d" },
-            { "zh_Hant", "\u091a\u0940\u0928\u0940 (\u092a\u093e\u0930\u092e\u094d\u092a\u0930\u093f\u0915)" },
+            { "zh_Hant", "\u0906\u0938\u093e\u0930-\u0916\u093e\u0928\u094d\u0925\u093f\u092f\u093e\u0930\u093f \u091a\u093e\u0907\u0928\u0940\u091c" },
             { "Sund", "\u0938\u0942\u0921\u093e\u0928\u0940" },
             { "kpe", "\u0915\u094d\u092a\u0947\u0932\u0947" },
             { "ilo", "\u0908\u0932\u094b\u0915\u094b" },
