@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -157,7 +153,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "AU", "Austr\u00e0lia" },
             { "AW", "Aruba" },
             { "en_US", "angl\u00e8s americ\u00e0" },
-            { "AX", "Illes \u00c5land" },
+            { "AX", "Illes Aland" },
             { "mye", "myene" },
             { "AZ", "Azerbaidjan" },
             { "%%AREVELA", "armeni oriental" },
@@ -173,13 +169,13 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "BH", "Bahrain" },
             { "BI", "Burundi" },
             { "BJ", "Ben\u00edn" },
-            { "BL", "Saint Barth\u00e9lemy" },
+            { "BL", "Saint-Barth\u00e9lemy" },
             { "BM", "Bermudes" },
             { "kut", "kutenai" },
             { "myv", "mordovi\u00e0 erza" },
             { "BN", "Brunei" },
             { "BO", "Bol\u00edvia" },
-            { "BQ", "Carib Neerland\u00e8s" },
+            { "BQ", "Antilles Neerlandeses" },
             { "BR", "Brasil" },
             { "BS", "Bahames" },
             { "xog", "soga" },
@@ -285,7 +281,6 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "pcd", "picard" },
             { "tkl", "tokelau\u00e8s" },
             { "grb", "grebo" },
-            { "root", "arrel" },
             { "type.ca.indian", "calendari hind\u00fa" },
             { "rgn", "romany\u00e8s" },
             { "grc", "grec antic" },
@@ -306,7 +301,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "enm", "angl\u00e8s mitj\u00e0" },
             { "GM", "G\u00e0mbia" },
             { "GN", "Guinea" },
-            { "GP", "Guadeloupe" },
+            { "GP", "Guadalupe" },
             { "GQ", "Guinea Equatorial" },
             { "GR", "Gr\u00e8cia" },
             { "GS", "Illes Ge\u00f2rgia del Sud i Sandwich del Sud" },
@@ -314,6 +309,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "GU", "Guam" },
             { "pdc", "alemany pennsilvani\u00e0" },
             { "GW", "Guinea Bissau" },
+            { "rhg", "rohingya" },
             { "tli", "tlingit" },
             { "tlh", "klingoni\u00e0" },
             { "Talu", "nou tai lue" },
@@ -386,7 +382,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "KI", "Kiribati" },
             { "KM", "Comores" },
             { "Knda", metaValue_kn },
-            { "KN", "Saint Christopher i Nevis" },
+            { "KN", "Saint Kitts i Nevis" },
             { "Zinh", "heretat" },
             { "fr_CA", "franc\u00e8s canadenc" },
             { "KP", "Corea del Nord" },
@@ -563,7 +559,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "Loma", "loma" },
             { "015", "\u00c0frica septentrional" },
             { "SG", "Singapur" },
-            { "SH", "Saint Helena" },
+            { "SH", "Santa Helena" },
             { "type.lb.strict", "salt de l\u00ednia estricte" },
             { "017", "\u00c0frica central" },
             { "SI", "Eslov\u00e8nia" },
@@ -600,6 +596,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "TC", "Illes Turks i Caicos" },
             { "yav", "yangben" },
             { "TD", "Txad" },
+            { "Qaag", "zawgyi" },
             { "TF", "Territoris Australs Francesos" },
             { "ase", "llengua de signes americana" },
             { "TG", "Togo" },
@@ -654,8 +651,8 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "pro", "proven\u00e7al antic" },
             { "VC", "Saint Vincent i les Grenadines" },
             { "VE", "Vene\u00e7uela" },
-            { "VG", "Illes Verges Brit\u00e0niques" },
-            { "VI", "Illes Verges Nord-americanes" },
+            { "VG", "Illes Verges brit\u00e0niques" },
+            { "VI", "Illes Verges nord-americanes" },
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
             { "nog", "nogai" },
@@ -784,6 +781,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "scn", "sicili\u00e0" },
             { "aa", "\u00e0far" },
             { "ab", "abkhaz" },
+            { "Aran", "nastaliq" },
             { "ae", metaValue_ae },
             { "af", "afrikaans" },
             { "ak", "\u00e0kan" },
@@ -794,7 +792,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "%%SOLBA", "dialecte de Stolvizza/Solbica" },
             { "Jpan", metaValue_ja },
             { "ar", metaValue_ar },
-            { "Hrkt", "katakana o hiragana" },
+            { "Hrkt", "sil\u00b7labaris japonesos" },
             { "as", "assam\u00e8s" },
             { "sdc", "sasser\u00e8s" },
             { "Lina", "lineal A" },
@@ -968,7 +966,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "mas", "massai" },
             { "kj", "kuanyama" },
             { "kk", "kazakh" },
-            { "kl", "grenland\u00e8s" },
+            { "kl", "groenland\u00e8s" },
             { "km", metaValue_km },
             { "kn", metaValue_kn },
             { "ko", metaValue_ko },
@@ -1316,6 +1314,7 @@ public class LocaleNames_ca extends OpenListResourceBundle {
             { "krc", "karatxai-balkar" },
             { "inh", "ing\u00faix" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "careli\u00e0" },
             { "efi", "efik" },
             { "key.nu", "xifres" },
