@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -117,6 +113,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Zsym", "Samhlaidhean" },
             { "cch", "Atsam" },
             { "mwr", "Marwari" },
+            { "%%ARKAIKA", "Arkaika" },
             { "type.nu.lanatham", "\u00c0ireamhan Tai Tham Tham" },
             { "mwv", "Mentawai" },
             { "Tagb", "Tagbanwa" },
@@ -191,8 +188,10 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "BY", "A\u2019 Bhealaruis" },
             { "BZ", "A\u2019 Bheil\u00ecs" },
             { "type.ca.persian", "Am M\u00ecosachan Pearsach" },
+            { "%%CREISS", "Ogsatanais Chroissant" },
             { "type.nu.hebr", "\u00c0ireamhan na h-Eabhra" },
             { "CA", "Canada" },
+            { "Kits", "Litrichean beaga na Khitan" },
             { "CC", "Na h-Eileanan Chocos (Keeling)" },
             { "mzn", "Mazanderani" },
             { "CD", "Congo - Kinshasa" },
@@ -268,7 +267,9 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "chr", metaValue_chr },
             { "ER", "Eartra" },
             { "ES", "An Sp\u00e0innt" },
+            { "%%TUNUMIIT", "Tunumiit" },
             { "ET", "An Itiop" },
+            { "Vith", "Vithkuqi" },
             { "EU", "An t-Aonadh E\u00f2rpach" },
             { "elx", "Elamais" },
             { "type.ca.gregorian", "Am M\u00ecosachan Griogarach" },
@@ -285,17 +286,17 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Taml", "Taimil" },
             { "FR", "An Fhraing" },
             { "Kpel", metaValue_kpe },
-            { "%%SIMPLE", "SIMPLE" },
+            { "%%SIMPLE", "Samhlaidhean s\u00ecmplichte" },
             { "pcd", "Picard" },
             { "tkl", metaValue_TK },
             { "grb", "Grebo" },
-            { "root", "Root" },
             { "%%DAJNKO", "Aibidil Dajnko" },
             { "type.ca.indian", "M\u00ecosachan N\u00e0iseanta nan Innseachan" },
             { "rgn", "Romagnol" },
             { "grc", "Greugais \u00c0rsaidh" },
             { "GA", "Gabon" },
             { "tkr", "Tsakhur" },
+            { "type.nu.tnsa", "\u00c0ireamhan Tangsa" },
             { "GB", "An R\u00ecoghachd Aonaichte" },
             { "pcm", "Beurla Nig\u00e8iriach" },
             { "GD", "Grean\u00e0da" },
@@ -319,6 +320,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "pdc", "Gearmailtis Phennsylvania" },
             { "type.nu.mathmono", "\u00c0ireamhan matamataig aon-leud" },
             { "GW", "Gini-Bioso" },
+            { "rhg", "Rohingya" },
             { "tli", "Tlingit" },
             { "tlh", "Klingon" },
             { "Talu", "Tai Lue \u00d9r" },
@@ -327,6 +329,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "zxx", "Susbaint nach eil \u2019na ch\u00e0nan" },
             { "Jurc", "Jurchen" },
             { "tly", "Talysh" },
+            { "%%VIVARAUP", "Ogsatanais Vivaro-Ailpeach" },
             { "pdt", "Plautdietsch" },
             { "de_AT", "Gearmailtis na h-Ostaire" },
             { "Vaii", metaValue_vai },
@@ -414,7 +417,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "phn", "Phenicis" },
             { "Cyrs", "Cirilis Seann-Sl\u00e0bhais na h-Eaglaise" },
             { "gwi", "Gwich\u02bcin" },
-            { "%%LUNA1918", "LUNA1918" },
+            { "%%LUNA1918", "Litreachadh na Ruisise \u00e0s d\u00e8idh 1917" },
             { "nds", "Gearmailtis \u00ccochdarach" },
             { "LI", "Lichtenstein" },
             { "LK", "Sri Lanca" },
@@ -462,6 +465,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "MQ", "Mairtinic" },
             { "MR", "Morat\u00e0inea" },
             { "MS", "Montsarat" },
+            { "Chrs", "Khwarazm" },
             { "MT", "Malta" },
             { "cps", "Capiznon" },
             { "type.m0.ungegn", "Tar-litreachadh GEGN nan D\u00f9thchannan Aonaichte" },
@@ -475,6 +479,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "MZ", "M\u00f2saimbic" },
             { "Phli", "Pahlavi nan snaidh-sgr\u00ecobhaidhean" },
             { "NA", "An Namaib" },
+            { "%%ARANES", "Aranais" },
             { "202", "Afraga Deas air an t-Sathara" },
             { "type.ca.hebrew", "Am M\u00ecosachan Eabhrach" },
             { "type.co.dictionary", "\u00d2rdugh se\u00f2rsachaidh an fhaclair" },
@@ -504,6 +509,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Mero", "Meroiticeach" },
             { "crh", "Turcais Chriomach" },
             { "ang", "Seann-Bheurla" },
+            { "%%GRMISTR", "N\u00f2s-sgr\u00ecobhaidh Mhistral na h-Ogsatanaise" },
             { "OM", "Om\u00e0n" },
             { "%%PETR1708", "Litreachadh Pheadair 1708" },
             { "anp", "Angika" },
@@ -521,6 +527,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "PG", "Gini Nuadh Phaputhach" },
             { "PH", "Na h-Eileanan Filipineach" },
             { "PK", "Pagast\u00e0n" },
+            { "%%NICARD", "Ogsatanais Nice" },
             { "PL", "A\u2019 Ph\u00f2lainn" },
             { "ewo", "Ewondo" },
             { "PM", "Saint Pierre agus Miquelon" },
@@ -577,6 +584,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Mand", "Mandaean" },
             { "SB", "Eileanan Sholaimh" },
             { "twq", "Tasawaq" },
+            { "Tnsa", "Tangsa" },
             { "011", "Afraga an Iar" },
             { "SC", "Na h-Eileanan Sheiseall" },
             { "SD", "Sud\u00e0n" },
@@ -593,7 +601,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "SI", "An t-Sl\u00f2bhain" },
             { "type.nu.mymrtlng", "\u00c0ireamhan Tai Laing Mi\u00e0nmar" },
             { "018", "Ceann a Deas Afraga" },
-            { "SJ", "Svalbard agus Jan Mayen" },
+            { "SJ", "Svalbard is Jan Mayen" },
             { "019", "An D\u00e0 Aimeireaga" },
             { "SK", "An t-Sl\u00f2bhac" },
             { "Bamu", "Bamum" },
@@ -626,7 +634,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "TC", "Na h-Eileanan Turcach is Caiceo" },
             { "yav", "Yangben" },
             { "TD", "An t-Se\u00e0d" },
-            { "Qaag", "Qaag" },
+            { "Qaag", "Zawgyi" },
             { "TF", "Ranntairean a Deas na Frainge" },
             { "ase", "Cainnt-shanais na h-Aimeireaga" },
             { "TG", "Togo" },
@@ -673,7 +681,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "US", "Na St\u00e0itean Aonaichte" },
             { "haw", "C\u00e0nan Hawai\u2019i" },
             { "%%1959ACAD", "Bealaruisis Acadamaigeach" },
-            { "%%IVANCHOV", "IVANCHOV" },
+            { "%%IVANCHOV", "Bulgarian in 1899 orthography = Bulgairis le litreachadh na bliadhna 1899" },
             { "type.co.gb2312han", "\u00d2rdugh se\u00f2rsachaidh na S\u00ecnise Simplichte - GB2312" },
             { "UY", "Uruguaidh" },
             { "prg", "Pruisis" },
@@ -684,10 +692,11 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "VA", "Cathair na Bhatacain" },
             { "pro", "Seann-Phroven\u00e7al" },
             { "VC", "Naomh Bhionsant agus Eileanan Greanadach" },
-            { "%%HSISTEMO", "HSISTEMO" },
+            { "%%HSISTEMO", "Roghainn-\u00e8iginn stannardach litreachadh na h-Esperanto le h" },
             { "VE", "A\u2019 Bheiniseala" },
             { "VG", "Eileanan Breatannach na Maighdinn" },
             { "VI", "Eileanan na Maighdinn aig na SA" },
+            { "%%LEMOSIN", "Ogsatanais Lemosin" },
             { "Soyo", "Soyombo" },
             { "VN", "Bhiet-Nam" },
             { "VU", "Vanuatu" },
@@ -760,8 +769,10 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.nu.telu", "\u00c0ireamhan Telugu" },
             { "lou", "Cr\u00ectheol Louisiana" },
             { "loz", "Lozi" },
+            { "%%FONKIRSH", "C\u00f2dachadh Kirshenbaum na h-Aibidil Fuaim-e\u00f2laiche" },
             { "Nkgb", "Naxi Geba" },
-            { "%%ASANTE", "ASANTE" },
+            { "%%ASANTE", "Asante" },
+            { "%%AUVERN", "Auvernhat" },
             { "jmc", "Machame" },
             { "hif", "Hindis Fh\u00ecditheach" },
             { "type.nu.hansfin", "\u00c0ireamhan ionmhasail na S\u00ecnise Shimplichte" },
@@ -780,7 +791,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "nwc", "Newari Chlasaigeach" },
             { "udm", "Udmurt" },
             { "Khmr", metaValue_km },
-            { "%%FONNAPA", "FONNAPA" },
+            { "%%FONNAPA", "Aibidil Fhuaim-e\u00f2lach Aimeireaga a Tuath" },
             { "type.ca.islamic-rgsa", "Am M\u00ecosachan Ioslamach (Ar\u00e0ibia nan Sabhd, sealladh)" },
             { "Limb", "Limbu" },
             { "sad", "Sandawe" },
@@ -800,12 +811,15 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "sba", "Ngambay" },
             { "Guru", "Gurmukhi" },
             { "%%ALUKU", "Dual-chainnt Aluku" },
+            { "type.nu.diak", "\u00c0ireamhan Dives Akuru" },
             { "lua", "Luba-Lulua" },
             { "%%BISCAYAN", "Dual-chainnt Bizkaia" },
+            { "%%PEANO", "Peano" },
             { "type.nu.tirh", "\u00c0ireamhan Tirhuta" },
             { "type.d0.fwidth", "L\u00e0n-Leud" },
             { "sbp", "Sangu" },
             { "lui", "Luise\u00f1o" },
+            { "%%GRITAL", "N\u00f2s-sgr\u00ecobhaidh Eadailteach na h-Ogsatanaise" },
             { "nyn", "Nyankole" },
             { "nym", "Nyamwezi" },
             { "lun", "Lunda" },
@@ -831,6 +845,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "scn", "Sisilis" },
             { "aa", "Afar" },
             { "ab", "Abchasais" },
+            { "Aran", "Nastaliq" },
             { "bbc", "Batak Toba" },
             { "ae", metaValue_ae },
             { "af", "Afraganais" },
@@ -854,6 +869,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "az", "Asarbaide\u00e0nais" },
             { "Rohg", "Hanifi Rohingya" },
             { "Khoj", "Khojki" },
+            { "%%CISAUP", "Ogsatanais cios-Ailpeach" },
             { "%%OSOJS", "Dual-chainnt Oseacco/Osojane" },
             { "%%UNIFON", "Aibidil fuaim-e\u00f2lais Unifon" },
             { "ba", "Bashkir" },
@@ -915,6 +931,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "bfd", "Bafut" },
             { "type.lb.normal", "Brisidhean-loidhe \u00e0bhaisteach" },
             { "ro_MD", "Moldobhais" },
+            { "%%VECDRUKA", "Vec\u0101 Druka" },
             { "el", metaValue_el },
             { "en", "Beurla" },
             { "eo", "Esperanto" },
@@ -950,7 +967,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.m0.bgn", "Tar-litreachadh BGN nan St\u00e0itean Aonaichte" },
             { "umb", "Umbundu" },
             { "fr", "Fraingis" },
-            { "%%AKUAPEM", "AKUAPEM" },
+            { "%%AKUAPEM", "Akuapem" },
             { "sid", "Sidamo" },
             { "fy", "Fr\u00ecoslannais Shiarach" },
             { "ga", "Gaeilge" },
@@ -986,6 +1003,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "id", "Innd-Innsis" },
             { "type.nu.tibt", "\u00c0ireamhan na Tibeitise" },
             { "ie", "Interlingue" },
+            { "%%GASCON", "Ogsatanais Ghascogne" },
             { "ig", "Igbo" },
             { "ii", "Yi Sichuan" },
             { "frm", "Meadhan-Fhraingis" },
@@ -1020,6 +1038,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "mag", "Magahi" },
             { "maf", "Mafa" },
             { "mai", "Maithili" },
+            { "Ougr", "Seann-\u00d9igiurais" },
             { "smn", "S\u00e0mais Inari" },
             { "ka", metaValue_ka },
             { "mak", metaValue_mak },
@@ -1091,6 +1110,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "nl", "Duitsis" },
             { "nn", "Nynorsk na Nirribhidh" },
             { "no", "Nirribhis" },
+            { "%%PROVENC", "Ogsatanais Phrovence" },
             { "nr", "Ndebele Dheasach" },
             { "type.nu.modi", "\u00c0ireamhan Modi" },
             { "Osge", metaValue_osa },
@@ -1128,6 +1148,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "bqi", "Bakhtiari" },
             { "pl", "P\u00f2lainnis" },
             { "dum", "Meadhan-Dhuitsis" },
+            { "%%TONGYONG", "Tongyong" },
             { "type.nu.saur", "\u00c0ireamhan Saurashtra" },
             { "type.ca.dangi", "M\u00ecosachan Dangi" },
             { "%%VALLADER", "Vallader" },
@@ -1217,6 +1238,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "bua", "Buriat" },
             { "143", "Meadhan \u00c0isia" },
             { "te", metaValue_te },
+            { "Toto", "Toto" },
             { "145", "\u00c0isia an Iar" },
             { "tg", "Taidigis" },
             { "th", "C\u00e0nan nan T\u00e0idh" },
@@ -1237,7 +1259,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "ts", "Tsonga" },
             { "swb", "Comorais" },
             { "tt", "Tatarais" },
-            { "%%XSISTEMO", "XSISTEMO" },
+            { "%%XSISTEMO", "Roghainn-\u00e8iginn stannardach litreachadh na h-Esperanto le x" },
             { "dyu", "Dyula" },
             { "tw", "Twi" },
             { "ty", "C\u00e0nan Tahiti" },
@@ -1287,6 +1309,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "wa", "Walloon" },
             { "gag", "Gagauz" },
             { "syr", metaValue_syr },
+            { "Cpmn", "M\u00ecneothais Ch\u00ecopras" },
             { "type.nu.gong", "\u00c0ireamhan Gunjala Gondi" },
             { "Grek", metaValue_el },
             { "gan", "Gan" },
@@ -1297,7 +1320,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "zgh", "Tamazight Stannardach Moroco" },
             { "ar_001", "Nuadh-Arabais Stannardach" },
             { "Cans", "Sgr\u00ecobhadh Lideach Aonaichte nan T\u00f9sanach Canadach" },
-            { "%%FONXSAMP", "FONXSAMP" },
+            { "%%FONXSAMP", "Tar-sgr\u00ecobhadh X-SAMPA" },
             { "gay", "Gayo" },
             { "Mong", metaValue_mn },
             { "mnc", "Manchu" },
@@ -1344,6 +1367,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "%%MONOTON", "Greugais mhonotonach" },
             { "Geor", metaValue_ka },
             { "Shrd", "Sharada" },
+            { "%%LENGADOC", "Ogsatanais Lengadoc" },
             { "kmb", "Kimbundu" },
             { "type.nu.jpanfin", "\u00c0ireamhan ionmhasail na Seapanaise" },
             { "Cham", "Cham" },
@@ -1356,6 +1380,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "type.nu.olck", "\u00c0ireamhan Ol Chiki" },
             { "type.co.reformed", "\u00d2rdugh se\u00f2rsachaidh ath-leasaichte" },
             { "Tglg", metaValue_tl },
+            { "Yezi", "Yezidis" },
             { "%%ITIHASA", "Itihasa" },
             { "Palm", "Palmyrene" },
             { "ebu", "Embu" },
@@ -1373,15 +1398,18 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "Sund", "Sunda" },
             { "vep", "Veps" },
             { "kpe", metaValue_kpe },
+            { "%%GRCLASS", "N\u00f2s-sgr\u00ecobhaidh clasaigeach na h-Ogsatanaise" },
             { "type.nu.khmr", "\u00c0ireamhan Cm\u00e8ar" },
             { "Tirh", "Tirhuta" },
             { "ilo", "Iloko" },
             { "%%VALENCIA", "Valenci\u00e0" },
             { "Cprt", "C\u00ecoprasais" },
+            { "Diak", "Dives Akuru" },
             { "%%BAKU1926", "Abidil Laideann aonaichte na Turcaise" },
             { "%%IJEKAVSK", "S\u00e8irbis le fuaimneachadh Ijekavia" },
             { "mua", "Mundang" },
             { "type.nu.guru", "\u00c0ireamhan Gurmukhi" },
+            { "%%BORNHOLM", "Bornholmsk" },
             { "mul", "Iomadh c\u00e0nan" },
             { "%%PUTER", "Puter" },
             { "cad", "Caddo" },
@@ -1398,6 +1426,7 @@ public class LocaleNames_gd extends OpenListResourceBundle {
             { "inh", "Ingush" },
             { "krj", "Kinaray-a" },
             { "kri", "Krio" },
+            { "fa_AF", "Dari" },
             { "krl", "Cairealais" },
             { "%%OXENDICT", "Litreachadh faclair Oxford na Beurla" },
             { "efi", "Efik" },
