@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -247,7 +247,6 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "%%SIMPLE", "\u7b80\u5355\u82f1\u8bed" },
             { "tkl", "\u6258\u514b\u52b3\u8bed" },
             { "grb", "\u683c\u5217\u535a\u8bed" },
-            { "root", "\u6839\u8bed\u8a00" },
             { "%%DAJNKO", "\u8fbe\u91d1\u79d1\u5b57\u6bcd" },
             { "type.ca.indian", "\u5370\u5ea6\u56fd\u5b9a\u5386" },
             { "grc", "\u53e4\u5e0c\u814a\u8bed" },
@@ -275,6 +274,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "GU", "\u5173\u5c9b" },
             { "type.nu.mathmono", "\u6570\u5b66\u7b49\u5bbd\u6570\u5b57" },
             { "GW", "\u51e0\u5185\u4e9a\u6bd4\u7ecd" },
+            { "rhg", "\u7f57\u5174\u4e9a\u8bed" },
             { "tli", "\u7279\u6797\u5409\u7279\u8bed" },
             { "tlh", "\u514b\u6797\u8d21\u8bed" },
             { "Talu", "\u65b0\u50a3\u6587" },
