@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -282,6 +282,14 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
                "hora de Tonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "hora de Yuk\u00f3n",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "hora est\u00e1ndar de Alaska",
                "",
@@ -1438,7 +1446,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1644,7 +1652,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1906,7 +1914,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/El_Aaiun", "El Aai\u00fan" },
             { "timezone.excity.Africa/Freetown", "Freetown" },
             { "timezone.excity.Africa/Gaborone", "Gaborone" },
-            { "timezone.excity.Africa/Khartoum", "Jart\u00fan" },
+            { "timezone.excity.Africa/Khartoum", "Jartum" },
             { "timezone.excity.Africa/Kinshasa", "Kinshasa" },
             { "timezone.excity.Africa/Monrovia", "Monrovia" },
             { "timezone.excity.Africa/Ndjamena", "Yamena" },
@@ -2047,7 +2055,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Pago_Pago", "Pago Pago" },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Pacific/Tongatapu", "Tongatapu" },
-            { "timezone.excity.Africa/Addis_Ababa", "Addis Abeba" },
+            { "timezone.excity.Africa/Addis_Ababa", "Ad\u00eds Abeba" },
             { "timezone.excity.Africa/Brazzaville", "Brazzaville" },
             { "timezone.excity.Africa/Ouagadougou", "Uagadug\u00fa" },
             { "timezone.excity.America/Costa_Rica", "Costa Rica" },
@@ -2094,7 +2102,7 @@ public class TimeZoneNames_es extends TimeZoneNamesBundle {
             { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "timezone.excity.Indian/Antananarivo", "Antananarivo" },
             { "timezone.excity.Pacific/Guadalcanal", "Guadalcanal" },
-            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es Salaam" },
+            { "timezone.excity.Africa/Dar_es_Salaam", "Dar es-Salam" },
             { "timezone.excity.America/Blanc-Sablon", "Blanc-Sablon" },
             { "timezone.excity.America/Buenos_Aires", "Buenos Aires" },
             { "timezone.excity.America/Campo_Grande", "Campo Grande" },
